@@ -786,6 +786,7 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
         if (updateWidget)
             updateWidget();
         updateMetadata();
+        broadcastMetadata();
     }
 
     private void executeUpdateProgress() {
@@ -810,7 +811,7 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
      * @return True if a media is currently loaded, false otherwise
      */
     private boolean hasCurrentMedia() {
-        return mCurrentIndex >= 0 && mCurrentIndex < mMediaList.size();
+        return isValidIndex(mCurrentIndex);
     }
 
     private final Handler mHandler = new AudioServiceHandler(this);
@@ -1029,8 +1030,17 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
             } else {
 
                 if(mShuffling) {
-                    if(mPrevious.size() > 0)
+                    if(!mPrevious.isEmpty()){
                         mPrevIndex = mPrevious.peek();
+                        while (!isValidIndex(mPrevIndex)) {
+                            mPrevious.remove(mPrevious.size() - 1);
+                            if (mPrevious.isEmpty()) {
+                                mPrevIndex = -1;
+                                break;
+                            }
+                            mPrevIndex = mPrevious.peek();
+                        }
+                    }
                     // If we've played all songs already in shuffle, then either
                     // reshuffle or stop (depending on RepeatType).
                     if(mPrevious.size() + 1 == size) {
@@ -1068,6 +1078,10 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
         }
     }
 
+    private boolean isValidIndex(int position) {
+        return position >= 0 && position < mMediaList.size();
+    }
+
     private void initMediaSession() {
          ComponentName mediaButtonEventReceiver = new ComponentName(this,
                     RemoteControlClientReceiver.class);
@@ -1322,6 +1336,7 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
         broadcast.putExtra("album", media.getAlbum());
         broadcast.putExtra("duration", media.getLength());
         broadcast.putExtra("playing", playing);
+        broadcast.putExtra("package", "org.videolan.vlc");
 
         sendBroadcast(broadcast);
     }
@@ -1657,7 +1672,7 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
             Log.w(TAG, "Warning: empty media list, nothing to play !");
             return;
         }
-        if (mMediaList.size() > position && position >= 0) {
+        if (isValidIndex(position)) {
             mCurrentIndex = position;
         } else {
             Log.w(TAG, "Warning: positon " + position + " out of bounds");
@@ -1690,7 +1705,7 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
             Log.w(TAG, "Warning: empty media list, nothing to play !");
             return;
         }
-        if (index >= 0 && index < mMediaList.size()) {
+        if (isValidIndex(index)) {
             mCurrentIndex = index;
         } else {
             Log.w(TAG, "Warning: index " + index + " out of bounds");
