@@ -25,7 +25,6 @@ import android.content.Intent;
 import android.os.Build;
 import android.os.Bundle;
 import android.os.Handler;
-import android.os.Looper;
 import android.os.Message;
 import android.support.design.widget.FloatingActionButton;
 import android.support.design.widget.TabLayout;
@@ -268,6 +267,7 @@ public class AudioBrowserFragment extends MediaBrowserFragment implements SwipeR
             updateLists();
         else {
             updateEmptyView(mViewPager.getCurrentItem());
+            updatePlaylists();
         }
         mMediaLibrary.addUpdateHandler(mHandler);
         mMediaLibrary.setBrowser(this);
@@ -278,7 +278,6 @@ public class AudioBrowserFragment extends MediaBrowserFragment implements SwipeR
                 mSwipeRefreshLayout.setEnabled(current.getFirstVisiblePosition() == 0);
             }
         });
-        updatePlaylists();
     }
 
     // Focus support. Start.
@@ -465,11 +464,10 @@ public class AudioBrowserFragment extends MediaBrowserFragment implements SwipeR
                 return false;
             final MediaWrapper media = mediaList.get(0);
             final AudioBrowserListAdapter.ListItem listItem = adapter.getItem(position);
-            final String key = adapter.getKey(position);
             String message;
             Runnable action;
 
-            adapter.remove(position, key);
+            adapter.remove(position);
 
             if (mode == MODE_PLAYLIST) {
                 message = getString(R.string.playlist_deleted);
@@ -491,7 +489,7 @@ public class AudioBrowserFragment extends MediaBrowserFragment implements SwipeR
             UiTools.snackerWithCancel(getView(), message, action, new Runnable() {
                 @Override
                 public void run() {
-                    adapter.addItem(position, key, listItem);
+                    adapter.addItem(position, listItem);
                 }
             });
             return true;
@@ -863,20 +861,12 @@ public class AudioBrowserFragment extends MediaBrowserFragment implements SwipeR
     Runnable updatePlaylists = new Runnable() {
         @Override
         public void run() {
-            if (Looper.myLooper() != Looper.getMainLooper()) {
-                mHandler.post(new Runnable() {
-                    @Override
-                    public void run() {
-                        mPlaylistAdapter.clear();
-                    }
-                });
-            }
+            //DB playlists
+            ArrayList<AudioBrowserListAdapter.ListItem> dbPlaylists = mMediaLibrary.getPlaylistDbItems();
+            mPlaylistAdapter.addAllDBPlaylists(dbPlaylists);
             //File playlists
             ArrayList<MediaWrapper> playlists = mMediaLibrary.getPlaylistFilesItems();
             mPlaylistAdapter.addAll(playlists, AudioBrowserListAdapter.TYPE_PLAYLISTS);
-            //DB playlists
-            ArrayList<AudioBrowserListAdapter.ListItem> dbPlaylists = mMediaLibrary.getPlaylistDbItems();
-            mPlaylistAdapter.addAll(dbPlaylists);
 
             mAdaptersToNotify.add(mPlaylistAdapter);
             if (mReadyToDisplay && !mDisplaying)
