@@ -92,15 +92,17 @@ public class AudioBrowserListAdapter extends BaseAdapter implements SectionIndex
     public static class ListItem {
         final public String mTitle;
         final public String mSubTitle;
+        final public String mMediaKey;
         final public ArrayList<MediaWrapper> mMediaList;
         final public boolean mIsSeparator;
 
-        public ListItem(String title, String subTitle, MediaWrapper media, boolean isSeparator) {
+        public ListItem(String title, String subTitle, MediaWrapper media, boolean isSeparator, String mediaKey) {
             mMediaList = new ArrayList<>();
             if (media != null)
                 mMediaList.add(media);
             mTitle = title;
             mSubTitle = subTitle;
+            mMediaKey = mediaKey;
             mIsSeparator = isSeparator;
         }
     }
@@ -118,19 +120,6 @@ public class AudioBrowserListAdapter extends BaseAdapter implements SectionIndex
         mAlignMode = Integer.valueOf(preferences.getString("audio_title_alignment", "0"));
     }
 
-    public void addAll(final List<ListItem> items) {
-        mContext.runOnUiThread(new Runnable() {
-            @Override
-            public void run() {
-                for (ListItem item : items) {
-                    mMediaItemMap.put(item.mTitle, item);
-                    mItems.add(item);
-                }
-                Collections.sort(mItems, mItemsComparator);
-            }
-        });
-    }
-
     public void add(String title, String subTitle, MediaWrapper media) {
         add(title, subTitle, media, null);
     }
@@ -147,18 +136,32 @@ public class AudioBrowserListAdapter extends BaseAdapter implements SectionIndex
         if (mMediaItemMap.containsKey(mediaKey))
             mMediaItemMap.get(mediaKey).mMediaList.add(media);
         else {
-            ListItem item = new ListItem(title, subTitle, media, false);
+            ListItem item = new ListItem(title, subTitle, media, false, mediaKey);
             mMediaItemMap.put(mediaKey, item);
             mItems.add(item);
         }
     }
 
+    public void addAllDBPlaylists(final List<ListItem> items) {
+        mContext.runOnUiThread(new Runnable() {
+            @Override
+            public void run() {
+                clear();
+                for (ListItem item : items) {
+                    mMediaItemMap.put(item.mMediaKey, item);
+                    mItems.add(item);
+                }
+            }
+        });
+    }
+
     public void addAll(List<MediaWrapper> mediaList, final int type) {
         final LinkedList<MediaWrapper> list = new LinkedList<MediaWrapper>(mediaList);
         mContext.runOnUiThread(new Runnable() {
             @Override
             public void run() {
-                clear();
+                if (type != TYPE_PLAYLISTS)
+                    clear();
                 String title, subTitle, key;
                 for (MediaWrapper media : list) {
                     switch (type){
@@ -199,14 +202,14 @@ public class AudioBrowserListAdapter extends BaseAdapter implements SectionIndex
         });
     }
 
-    public void remove(int position, String key) {
+    public void remove(int position) {
+        mMediaItemMap.remove(mItems.get(position).mMediaKey);
         mItems.remove(position);
-        mMediaItemMap.remove(key);
         notifyDataSetChanged();
     }
 
-    public void addItem(int position, String key, ListItem item) {
-        mMediaItemMap.put(key, item);
+    public void addItem(int position, ListItem item) {
+        mMediaItemMap.put(item.mMediaKey, item);
         mItems.add(position, item);
         notifyDataSetChanged();
     }
@@ -224,6 +227,8 @@ public class AudioBrowserListAdapter extends BaseAdapter implements SectionIndex
         char prevFirstChar = '%';
         boolean firstSeparator = true;
         ArrayList<String> sections = new ArrayList<>();
+        if (type == TYPE_PLAYLISTS)
+            Collections.sort(mItems, mItemsComparator);
 
         for (int i = 0; i < mItems.size(); ++i) {
             String title = mItems.get(i).mTitle;
@@ -250,7 +255,7 @@ public class AudioBrowserListAdapter extends BaseAdapter implements SectionIndex
             if (Character.isLetter(firstChar)) {
                 String firstCharInString = String.valueOf(firstChar);
                 if ((firstSeparator || firstChar != prevFirstChar) && !sections.contains(firstCharInString)) {
-                    ListItem item = new ListItem(firstCharInString, null, null, true);
+                    ListItem item = new ListItem(firstCharInString, null, null, true, null);
                     mItems.add(i, item);
                     mSections.put(i, String.valueOf(firstChar));
                     i++;
@@ -259,7 +264,7 @@ public class AudioBrowserListAdapter extends BaseAdapter implements SectionIndex
                     sections.add(firstCharInString);
                 }
             } else if (firstSeparator) {
-                ListItem item = new ListItem("#", null, null, true);
+                ListItem item = new ListItem("#", null, null, true, null);
                 mItems.add(i, item);
                 mSections.put(i, "#");
                 i++;
@@ -276,7 +281,7 @@ public class AudioBrowserListAdapter extends BaseAdapter implements SectionIndex
         if (mSeparatorItemMap.containsKey(titleKey))
             mSeparatorItemMap.get(titleKey).mMediaList.add(media);
         else {
-            ListItem item = new ListItem(title, null, media, true);
+            ListItem item = new ListItem(title, null, media, true, null);
             mSeparatorItemMap.put(titleKey, item);
             mItems.add(item);
         }
