@@ -353,7 +353,7 @@ public abstract class BaseBrowserFragment extends MediaBrowserFragment implement
         if (mRoot)
             browseRoot();
         else
-            mMediaBrowser.browse(mCurrentMedia != null ? mCurrentMedia.getUri() : Uri.parse(mMrl), true);
+            mMediaBrowser.browse(mCurrentMedia != null ? mCurrentMedia.getUri() : Uri.parse(mMrl), getBrowserFlags());
     }
 
     private void deleteMedia(final MediaWrapper mw) {
@@ -374,6 +374,10 @@ public abstract class BaseBrowserFragment extends MediaBrowserFragment implement
         }
     }
 
+    protected int getBrowserFlags() {
+        return MediaBrowser.Flag.Interact;
+    }
+
     protected static class BrowserFragmentHandler extends WeakHandler<BaseBrowserFragment> {
 
         public static final int MSG_SHOW_LOADING = 0;
@@ -588,7 +592,7 @@ public abstract class BaseBrowserFragment extends MediaBrowserFragment implement
                 mw = null;
             if (mw != null){
                 if (mw.getType() == MediaWrapper.TYPE_DIR || mw.getType() == MediaWrapper.TYPE_PLAYLIST){
-                    mMediaBrowser.browse(mw.getUri(), false);
+                    mMediaBrowser.browse(mw.getUri(), 0);
                     return;
                 }
             }
@@ -641,7 +645,7 @@ public abstract class BaseBrowserFragment extends MediaBrowserFragment implement
 
             if (mw != null) {
                 if (mCurrentParsedPosition < mAdapter.getItemCount()) {
-                    mMediaBrowser.browse(mw.getUri(), false);
+                    mMediaBrowser.browse(mw.getUri(), 0);
                 } else {
                     mCurrentParsedPosition = -1;
                     releaseBrowser();
