@@ -20,6 +20,7 @@
 
 package org.videolan.vlc.util;
 
+import android.app.Activity;
 import android.content.Context;
 import android.content.Intent;
 import android.content.res.AssetManager;
@@ -136,8 +137,10 @@ public class VLCInstance {
 
     public static synchronized boolean testCompatibleCPU(Context context) {
         if (sLibVLC == null && !VLCUtil.hasCompatibleCPU(context)) {
-            final Intent i = new Intent(context, CompatErrorActivity.class);
-            context.startActivity(i);
+            if (context instanceof Activity) {
+                final Intent i = new Intent(context, CompatErrorActivity.class);
+                context.startActivity(i);
+            }
             return false;
         } else
             return true;
